@@ -4,6 +4,10 @@
 #' residuals, a la Dunn and Smyth (1996). Checks of \code{k} are not computed,
 #' these need to be done using \code{\link{gam.check}}.
 #'
+#' In general plots other than residuals vs. linear predictors should be interpreted with caution (for example Q-Q plots and histogram of residuals will look normal by construction -- so there is no model checking information).
+#'
+#' Note that this function only works with negative binomial and Tweedie response distributions.
+#'
 #' @param gam.obj a \code{gam}, \code{glm} or \code{dsm} object.
 #' @param ... arguments passed on to all plotting functions
 #' @return just plots!
@@ -22,15 +26,19 @@
 #'
 #' # load the Gulf of Mexico dolphin data (see ?mexdolphins)
 #' data(mexdolphins)
+#' attach(mexdolphins)
 #'
 #' # fit a detection function and look at the summary
-#' hr.model <- ds(mexdolphins$distdata, max(mexdolphins$distdata$distance),
+#' hr.model <- ds(distdata, max(distdata$distance),
 #'                key = "hr", adjustment = NULL)
 #'
 #' # fit a simple smooth of x and y with a Tweedie response with estimated
 #' #  p parameter
-#' mod1<-dsm(N~s(x,y), hr.model, mexdolphins$segdata, mexdolphins$obsdata, family=tw())
+#' mod1<-dsm(N~s(x,y), hr.model, segdata, obsdata, family=tw())
 #' rqgam.check(mod1)
+#'
+#' # detach the data
+#' detach("mexdolphins")
 #' }
 rqgam.check<-function(gam.obj,...){
 
@@ -59,8 +67,7 @@ rqgam.check<-function(gam.obj,...){
     }
     qres <- qres.nbinom(gam.obj)
   }else{
-    # for everything else
-    qres <- qresid(gam.obj)
+    stop("Only negative binomial and Tweedie response distributions are supported.")
   }
 
   # values of the linear predictor
