@@ -9,10 +9,11 @@ context("Mexico pantropical dolphin data")
 
 # load the Gulf of Mexico dolphin data
 data(mexdolphins)
+attach(mexdolphins)
 
 # fit a detection function and look at the summary
-hn.model <- suppressMessages(ds(mexdolphins$distdata,
-                                max(mexdolphins$distdata$distance),
+hn.model <- suppressMessages(ds(distdata,
+                                max(distdata$distance),
                                 adjustment = NULL))
 
 test_that("Do we get the same results?",{
@@ -20,27 +21,27 @@ test_that("Do we get the same results?",{
 
   ddf.par <- 8.626542
   names(hn.model$ddf$par) <- NULL
-  expect_that(hn.model$ddf$par, equals(ddf.par,tolerance=par.tol))
+  expect_equal(hn.model$ddf$par, ddf.par, tolerance=par.tol)
 
   # fit a simple smooth of x and y
-  mod1<-dsm(N~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata)
+  mod1<-dsm(N~s(x,y), hn.model, segdata, obsdata)
   #summary(mod1)
 
 
-  expect_that(mod1$gcv.ubre, equals(42.9169051,tolerance=par.tol))
+  expect_equal(unname(mod1$gcv.ubre), 42.9169051,tolerance=par.tol)
 
 
-  expect_that(dsm.cor(mod1,resid.type="d",max.lag=9),
-              throws_error("No column called Segment.Label in data"))
+  expect_error(dsm.cor(mod1,resid.type="d",max.lag=9),
+               "No column called Segment.Label in data")
 })
 
 test_that("Density weighting",{
 
   # fit density model
-  mod1 <- dsm(D~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata)
+  mod1 <- dsm(D~s(x,y), hn.model, segdata, obsdata)
 
   # compare when we set the weights
-  mod1.w <- dsm(D~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata,
+  mod1.w <- dsm(D~s(x,y), hn.model, segdata, obsdata,
                 weights=mod1$data$segment.area)
 
   expect_equal(fitted(mod1),fitted(mod1.w),tolerance=par.tol)
@@ -48,19 +49,20 @@ test_that("Density weighting",{
 
   # setting weights to 1 or another constant
   # compare when we set the weights
-  mod1.w1 <- dsm(D~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata,
-                weights=rep(1,nrow(mexdolphins$segdata)))
+  mod1.w1 <- dsm(D~s(x,y), hn.model, segdata, obsdata,
+                weights=rep(1,nrow(segdata)))
   # compare when we set the weights
-  mod1.w2 <- dsm(D~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata,
-                weights=rep(100,nrow(mexdolphins$segdata)))
+  mod1.w2 <- dsm(D~s(x,y), hn.model, segdata, obsdata,
+                weights=rep(100,nrow(segdata)))
 
   expect_equal(fitted(mod1.w1),fitted(mod1.w2),tolerance=par.tol)
 
   # scalar input of weights (same as weighting all as 1, or 10)
-  mod1.ws1 <- dsm(D~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata,
+  mod1.ws1 <- dsm(D~s(x,y), hn.model, segdata, obsdata,
                 weights=1)
 
   expect_equal(fitted(mod1.ws1),fitted(mod1.w2),tolerance=par.tol)
 
 })
 
+detach("mexdolphins")
